==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/sk_SK.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumenty",
    "Can't create document" : "Nedá sa vytvoriť dokument",
    "You don't have permission to rename this document" : "Nemáte oprávnenie na premenovanie tohto dokumentu",
    "Directory saved successfully." : "Priečinok bol úspešne uložený.",
    "An error occurred while changing directory." : "Pri pokuse o zmenu priečinka nastala chyba.",
    "Saved" : "Uložené",
    "Format filter server is down or misconfigured" : "Server pre spracovanie formátu je nedostupný alebo chybne nakonfigurovaný",
    "Conversion failed. Check log for details." : "Konverzia zlyhala. Podrobnosti uvidíte v protokole.",
    "bold" : "tučné",
    "italic" : "kurzíva",
    "Saving..." : "Ukladám...",
    "Failed to load documents." : "Nepodarilo sa načítať dokumenty.",
    "No documents were found. Upload or create a document to get started!" : "Neboli nájdené žiadne dokumenty. Začnite tým, že nahráte alebo vytvoríte dokument.",
    "No connection to server. Trying to reconnect." : "Nie je pripojenie k serveru. Pokúste sa o znovupripojenie.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Ponechaním tejto stránky v editačnom móde môže dôjsť k tomu, že sa zmeny neuložia. Doporučujeme použiť tlačidlo 'Zavrieť'",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Nepodarilo sa otvoriť tento dokument. Skontrolujte prosím, či je možné ho otvoriť externým editorom ODT súborov. Môže to však tiež znamenať, že bolo zdieľanie zrušené, alebo bol vymazaný.",
    "Save" : "Uložiť",
    "Loading documents..." : "Nahrávam dokumenty...",
    "'.' is an invalid file name." : "'.' je neplatné meno súboru.",
    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nesprávne meno, '\\', '/', '<', '>', ':', '\"', '|', '?' a '*' nie sú povolené hodnoty.",
    "Align Left" : "Zarovnanie vľavo",
    "Alignment" : "Zarovnanie",
    "Align Right" : "Zarovnanie vpravo",
    "Annotate" : "Anotácia",
    "Background" : "Pozadie",
    "Bold" : "Tučné",
    "Bottom" : "Nadol",
    "Cancel" : "Zrušiť",
    "Center" : "Na stred",
    "Clone" : "Klonovať",
    "Clone this Style" : "Klonovať tento štýl",
    "Close" : "Zavrieť",
    "Color" : "Farba",
    "Create" : "Vytvoriť",
    "Decrease Indent" : "Zmenšiť odsadenie",
    "Default Style" : "Predvolený štýl",
    "Delete" : "Zmazať",
    "Family" : "Rodina",
    "Font" : "Font",
    "Font Effects" : "Efekty písma",
    "Format" : "Formát",
    "Increase Indent" : "Zväčšiť odsadenie",
    "Insert Image" : "Vložiť obrázok",
    "Invite Members" : "Pozvať členov",
    "Italic" : "Kurzíva",
    "Justified" : "Zarovnaný",
    "Justify" : "Zarovnať",
    "Left" : "Vľavo",
    "Loading" : "Nahrávam",
    "Members" : "Členovia",
    "New Name:" : "Nový názov:",
    "OK" : "OK",
    "Open" : "Otvoriť",
    "Options" : "Možnosti",
    "Paragraph..." : "Odsek...",
    "Paragraph Styles" : "Štýly odseku",
    "Redo" : "Znovu",
    "Right" : "Vpravo",
    "Size" : "Veľkosť",
    "Spacing" : "Riadkovanie",
    "Strikethrough" : "Prečiarknuté",
    "Style" : "Štýl",
    "Text" : "Text",
    "Top" : "Horný",
    "Underline" : "Podčiarknuť",
    "Undo" : "Späť",
    "Unknown Author" : "Neznámy autor",
    "Edit" : "Upraviť",
    "Share" : "Zdieľať",
    "guest" : "hosť",
    "MS Word support (requires openOffice/libreOffice)" : "Podpora MS Word (vyžaduje sa openOffice/libreOffice)",
    "Local" : "Lokálny",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice je nainštalovaný na tomto serveri. Cesta k spustiteľnému súboru je zaznamenaná pod preview_libreoffice_path v config.php",
    "External" : "Externý",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffie je nainštalovaný na externom serveri, kde beží inštancia filtrujúca formáty",
    "Disabled" : "Zakázané",
    "No MS Word support" : "Žiadna podpora MS Word",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "Server URL",
    "Apply and test" : "Použiť a odskúšať",
    "New document" : "Nový dokument",
    "Upload (max. %s)" : "Nahrať (max. %s)",
    "Upload" : "Odoslať",
    "Save new documents to" : "Uložiť nové dokumenty do",
    "Wrong password. Please retry." : "Chybné heslo. Skúste to znovu.",
    "Password" : "Heslo",
    "Guest %s" : "Hosť %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Tento odkaz vyexpiroval, alebo neexistuje. Pre podrobnosti kontaktujte osobu, ktorá ho s vami zdieľala.",
    "Advanced feature-set" : "Rozšírená sada možností",
    "(Unstable)" : "(Nestabilý)"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/sk_SK.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumenty",
    "Can't create document" : "Nedá sa vytvoriť dokument",
    "You don't have permission to rename this document" : "Nemáte oprávnenie na premenovanie tohto dokumentu",
    "Directory saved successfully." : "Priečinok bol úspešne uložený.",
    "An error occurred while changing directory." : "Pri pokuse o zmenu priečinka nastala chyba.",
    "Saved" : "Uložené",
    "Format filter server is down or misconfigured" : "Server pre spracovanie formátu je nedostupný alebo chybne nakonfigurovaný",
    "Conversion failed. Check log for details." : "Konverzia zlyhala. Podrobnosti uvidíte v protokole.",
    "Saving..." : "Ukladám...",
    "Failed to load documents." : "Nepodarilo sa načítať dokumenty.",
    "No documents were found. Upload or create a document to get started!" : "Neboli nájdené žiadne dokumenty. Začnite tým, že nahráte alebo vytvoríte dokument.",
    "No connection to server. Trying to reconnect." : "Nie je pripojenie k serveru. Pokúste sa o znovupripojenie.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Ponechaním tejto stránky v editačnom móde môže dôjsť k tomu, že sa zmeny neuložia. Doporučujeme použiť tlačidlo 'Zavrieť'",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Nepodarilo sa otvoriť tento dokument. Skontrolujte prosím, či je možné ho otvoriť externým editorom ODT súborov. Môže to však tiež znamenať, že bolo zdieľanie zrušené, alebo bol vymazaný.",
    "Save" : "Uložiť",
    "Loading documents..." : "Nahrávam dokumenty...",
    "'.' is an invalid file name." : "'.' je neplatné meno súboru.",
    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nesprávne meno, '\\', '/', '<', '>', ':', '\"', '|', '?' a '*' nie sú povolené hodnoty.",
    "Align Left" : "Zarovnanie vľavo",
    "Alignment" : "Zarovnanie",
    "Align Right" : "Zarovnanie vpravo",
    "Annotate" : "Anotácia",
    "Background" : "Pozadie",
    "Bold" : "Tučné",
    "Bottom" : "Nadol",
    "Cancel" : "Zrušiť",
    "Center" : "Na stred",
    "Clone" : "Klonovať",
    "Clone this Style" : "Klonovať tento štýl",
    "Close" : "Zavrieť",
    "Color" : "Farba",
    "Create" : "Vytvoriť",
    "Decrease Indent" : "Zmenšiť odsadenie",
    "Default Style" : "Predvolený štýl",
    "Delete" : "Zmazať",
    "Family" : "Rodina",
    "Font" : "Font",
    "Font Effects" : "Efekty písma",
    "Format" : "Formát",
    "Increase Indent" : "Zväčšiť odsadenie",
    "Insert Image" : "Vložiť obrázok",
    "Invite Members" : "Pozvať členov",
    "Italic" : "Kurzíva",
    "Justified" : "Zarovnaný",
    "Justify" : "Zarovnať",
    "Left" : "Vľavo",
    "Loading" : "Nahrávam",
    "Members" : "Členovia",
    "New Name:" : "Nový názov:",
    "OK" : "OK",
    "Open" : "Otvoriť",
    "Options" : "Možnosti",
    "Paragraph..." : "Odsek...",
    "Paragraph Styles" : "Štýly odseku",
    "Redo" : "Znovu",
    "Right" : "Vpravo",
    "Size" : "Veľkosť",
    "Spacing" : "Riadkovanie",
    "Strikethrough" : "Prečiarknuté",
    "Style" : "Štýl",
    "Text" : "Text",
    "Top" : "Horný",
    "Underline" : "Podčiarknuť",
    "Undo" : "Späť",
    "Unknown Author" : "Neznámy autor",
    "Shared" : "Zdieľané",
    "Error" : "Chyba",
    "Error while sharing" : "Chyba počas zdieľania",
    "Error while unsharing" : "Chyba počas ukončenia zdieľania",
    "Error while changing permissions" : "Chyba počas zmeny oprávnení",
    "Shared with you and the group {group} by {owner}" : "Zdieľané s vami a so skupinou {group} používateľom {owner}",
    "Shared with you by {owner}" : "Zdieľané s vami používateľom {owner}",
    "Share with users or groups …" : "Zdieľať s používateľmi alebo skupinami ...",
    "Share with users, groups or remote users …" : "Zdieľať s používateľmi, skupinami alebo vzdialenými používateľmi ...",
    "Share" : "Zdieľať",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Zdieľať s ľuďmi na iných serveroch ownClouds pomocou syntaxe používateľ@doména.com/owncloud",
    "Share link" : "Zdieľať linku",
    "The public link will expire no later than {days} days after it is created" : "Verejný odkaz nevyprší skôr než za {days} dní po vytvorení",
    "Link" : "Odkaz",
    "Password protect" : "Chrániť heslom",
    "Password" : "Heslo",
    "Choose a password for the public link" : "Zadajte heslo pre tento verejný odkaz",
    "Allow editing" : "Povoliť úpravy",
    "Email link to person" : "Odoslať odkaz emailom",
    "Send" : "Odoslať",
    "Set expiration date" : "Nastaviť dátum expirácie",
    "Expiration" : "Koniec platnosti",
    "Expiration date" : "Dátum expirácie",
    "An error occured. Please try again" : "Nastala chyba. Skúste to znovu",
    "Adding user..." : "Pridávam používateľa...",
    "group" : "skupina",
    "remote" : "vzdialený",
    "Resharing is not allowed" : "Zdieľanie už zdieľanej položky nie je povolené",
    "Shared in {item} with {user}" : "Zdieľané v {item} s {user}",
    "Unshare" : "Zrušiť zdieľanie",
    "notify by email" : "informovať emailom",
    "can share" : "môže zdieľať",
    "can edit" : "môže upraviť",
    "access control" : "prístupové práva",
    "create" : "vytvoriť",
    "change" : "zmeniť",
    "delete" : "vymazať",
    "Password protected" : "Chránené heslom",
    "Error unsetting expiration date" : "Chyba pri odstraňovaní dátumu expirácie",
    "Error setting expiration date" : "Chyba pri nastavení dátumu expirácie",
    "Sending ..." : "Odosielam ...",
    "Email sent" : "Email odoslaný",
    "Warning" : "Upozornenie",
    "Edit" : "Upraviť",
    "guest" : "hosť",
    "MS Word support (requires openOffice/libreOffice)" : "Podpora MS Word (vyžaduje sa openOffice/libreOffice)",
    "Local" : "Lokálny",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice je nainštalovaný na tomto serveri. Cesta k spustiteľnému súboru je zaznamenaná pod preview_libreoffice_path v config.php",
    "External" : "Externý",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffie je nainštalovaný na externom serveri, kde beží inštancia filtrujúca formáty",
    "Disabled" : "Zakázané",
    "No MS Word support" : "Žiadna podpora MS Word",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "Server URL",
    "Apply and test" : "Použiť a odskúšať",
    "New document" : "Nový dokument",
    "Upload (max. %s)" : "Nahrať (max. %s)",
    "Upload" : "Odoslať",
    "Save new documents to" : "Uložiť nové dokumenty do",
    "Wrong password. Please retry." : "Chybné heslo. Skúste to znovu.",
    "Guest %s" : "Hosť %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Tento odkaz vyexpiroval, alebo neexistuje. Pre podrobnosti kontaktujte osobu, ktorá ho s vami zdieľala.",
    "Advanced feature-set" : "Rozšírená sada možností",
    "(Unstable)" : "(Nestabilý)"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
